@@ -401,8 +401,8 @@ _read_bytes (int      fd,
         if (premature_eof) {
                 g_set_error (error,
                              G_FILE_ERROR,
-                             G_FILE_ERROR_FAILED,
-                             "No data available");
+                             g_file_error_from_errno (ENODATA),
+                             "%s", g_strerror (ENODATA));
 
                 return FALSE;
         } else if (bytes_left_to_read > 0) {
