@@ -43,6 +43,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "gdm-common.h"
 #include "gdm-greeter-server.h"
 
 #define GDM_GREETER_SERVER_DBUS_PATH      "/org/gnome/DisplayManager/GreeterServer"
@@ -238,13 +239,6 @@ gdm_greeter_server_problem (GdmGreeterServer *greeter_server,
         return TRUE;
 }
 
-gboolean
-gdm_greeter_server_authentication_failed (GdmGreeterServer *greeter_server)
-{
-        send_dbus_void_signal (greeter_server, "AuthenticationFailed");
-        return TRUE;
-}
-
 gboolean
 gdm_greeter_server_reset (GdmGreeterServer *greeter_server)
 {
@@ -769,8 +763,6 @@ do_introspect (DBusConnection *connection,
                                "    </signal>\n"
                                "    <signal name=\"Reset\">\n"
                                "    </signal>\n"
-                               "    <signal name=\"AuthenticationFailed\">\n"
-                               "    </signal>\n"
                                "    <signal name=\"UserAuthorized\">\n"
                                "    </signal>\n"
                                "  </interface>\n");
@@ -894,7 +886,7 @@ allow_user_function (DBusConnection *connection,
                 return FALSE;
         }
 
-        pwent = getpwnam (greeter_server->priv->user_name);
+        gdm_get_pwent_for_name (greeter_server->priv->user_name, &pwent);
         if (pwent == NULL) {
                 return FALSE;
         }
