@@ -39,13 +39,14 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "gdm-xerrors.h"
 #include "gdm-signal-handler.h"
 #include "gdm-log.h"
 #include "gdm-common.h"
 #include "gdm-simple-slave.h"
 #include "gdm-settings.h"
 #include "gdm-settings-direct.h"
-
+#include "gdm-settings-keys.h"
 #include "gdm-settings-client.h"
 
 static GdmSettings     *settings        = NULL;
@@ -154,14 +155,17 @@ on_slave_stopped (GdmSlave   *slave,
 }
 
 static gboolean
-is_debug_set (gboolean arg)
+is_debug_set (void)
 {
+        gboolean debug = FALSE;
+
         /* enable debugging for unstable builds */
         if (gdm_is_version_unstable ()) {
                 return TRUE;
         }
 
-        return arg;
+        gdm_settings_direct_get_boolean (GDM_KEY_DEBUG, &debug);
+        return debug;
 }
 
 int
@@ -173,11 +177,9 @@ main (int    argc,
         DBusGConnection  *connection;
         GdmSlave         *slave;
         static char      *display_id = NULL;
-        static gboolean   debug      = FALSE;
         GdmSignalHandler *signal_handler;
         static GOptionEntry entries []   = {
-                { "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable debugging code"), NULL },
-                { "display-id", 0, 0, G_OPTION_ARG_STRING, &display_id, N_("Display ID"), N_("id") },
+                { "display-id", 0, 0, G_OPTION_ARG_STRING, &display_id, N_("Display ID"), N_("ID") },
                 { NULL }
         };
 
@@ -203,6 +205,7 @@ main (int    argc,
                 goto out;
         }
 
+        gdm_xerrors_init ();
         gdm_log_init ();
 
         settings = gdm_settings_new ();
@@ -216,7 +219,7 @@ main (int    argc,
                 goto out;
         }
 
-        gdm_log_set_debug (is_debug_set (debug));
+        gdm_log_set_debug (is_debug_set ());
 
         if (display_id == NULL) {
                 g_critical ("No display ID set");
