@@ -818,9 +818,6 @@ get_normalized_position_of_row_at_path (GdmChooserWidget *widget,
 {
         GdkRectangle area_of_row_at_path;
         GdkRectangle area_of_visible_rows;
-        GtkAllocation items_view_allocation;
-
-        gtk_widget_get_allocation (widget->priv->items_view, &items_view_allocation);
 
         gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget->priv->items_view),
                                            path, NULL, &area_of_row_at_path);
@@ -830,7 +827,7 @@ get_normalized_position_of_row_at_path (GdmChooserWidget *widget,
                                                      area_of_visible_rows.y,
                                                      &area_of_visible_rows.x,
                                                      &area_of_visible_rows.y);
-        return CLAMP (((double) area_of_row_at_path.y) / items_view_allocation.height, 0.0, 1.0);
+        return CLAMP (((double) area_of_row_at_path.y) / widget->priv->items_view->allocation.height, 0.0, 1.0);
 }
 
 static void
@@ -909,12 +906,12 @@ _grab_focus (GtkWidget *widget)
 
         foc_widget = GDM_CHOOSER_WIDGET (widget)->priv->items_view;
         g_debug ("GdmChooserWidget: grabbing focus");
-        if (! gtk_widget_get_realized (foc_widget)) {
+        if (! GTK_WIDGET_REALIZED (foc_widget)) {
                 g_debug ("GdmChooserWidget: not grabbing focus - not realized");
                 return;
         }
 
-        if (gtk_widget_has_focus (foc_widget)) {
+        if (GTK_WIDGET_HAS_FOCUS (foc_widget)) {
                 g_debug ("GdmChooserWidget: not grabbing focus - already has it");
                 return;
         }
@@ -982,22 +979,16 @@ on_grow_animation_step (GdmScrollableWidget *scrollable_widget,
         number_of_visible_rows = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (widget->priv->model_sorter), NULL);
         number_of_on_screen_rows = get_number_of_on_screen_rows (widget);
 
-        GtkRequisition scrollable_widget_req;
-        gtk_widget_get_requisition (gtk_bin_get_child (GTK_BIN (scrollable_widget)), &scrollable_widget_req);
-        *new_height = scrollable_widget_req.height;
+        *new_height = GTK_BIN (scrollable_widget)->child->requisition.height;
 }
 
 static void
 start_grow_animation (GdmChooserWidget *widget)
 {
-        GtkRequisition scrollable_widget_req;
-        gtk_widget_get_requisition (gtk_bin_get_child (GTK_BIN (widget->priv->scrollable_widget)),
-                                    &scrollable_widget_req);
-
         set_inactive_items_visible (widget, TRUE);
 
         gdm_scrollable_widget_slide_to_height (GDM_SCROLLABLE_WIDGET (widget->priv->scrollable_widget),
-                                               scrollable_widget_req.height,
+                                               GTK_BIN (widget->priv->scrollable_widget)->child->requisition.height,
                                                (GdmScrollableWidgetSlideStepFunc)
                                                on_grow_animation_step, widget,
                                                (GdmScrollableWidgetSlideDoneFunc)
@@ -1038,7 +1029,7 @@ gdm_chooser_widget_grow (GdmChooserWidget *widget)
 
         widget->priv->state = GDM_CHOOSER_WIDGET_STATE_GROWING;
 
-        if (gtk_widget_get_visible (GTK_WIDGET (widget))) {
+        if (GTK_WIDGET_VISIBLE (widget)) {
                 start_grow_animation (widget);
         } else {
                 skip_resize_animation (widget);
@@ -1112,7 +1103,7 @@ gdm_chooser_widget_shrink (GdmChooserWidget *widget)
 
         widget->priv->state = GDM_CHOOSER_WIDGET_STATE_SHRINKING;
 
-        if (gtk_widget_get_visible (GTK_WIDGET (widget))) {
+        if (GTK_WIDGET_VISIBLE (widget)) {
                 start_shrink_animation (widget);
         } else {
                 skip_resize_animation (widget);
@@ -1385,7 +1376,7 @@ gdm_chooser_widget_focus (GtkWidget        *widget,
          *    that focus.
          *    2) if it doesn't already have focus, then grab it
          */
-        if (gtk_container_get_focus_child (GTK_CONTAINER (widget)) != NULL) {
+        if (GTK_CONTAINER (widget)->focus_child != NULL) {
                 g_debug ("GdmChooserWidget: not focusing - focus child not null");
                 return FALSE;
         }
@@ -1973,7 +1964,7 @@ gdm_chooser_widget_init (GdmChooserWidget *widget)
          * works on us.  We then override grab_focus requests to
          * be redirected our internal tree view
          */
-        gtk_widget_set_can_focus (GTK_WIDGET (widget), TRUE);
+        GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
 
         gtk_alignment_set_padding (GTK_ALIGNMENT (widget), 0, 0, 0, 0);
 
