@@ -40,8 +40,8 @@
 #include <gconf/gconf-client.h>
 #include <dbus/dbus-glib.h>
 
-#ifdef HAVE_UPOWER
-#include <upower.h>
+#ifdef HAVE_DEVICEKIT_POWER
+#include <devkit-power-gobject/devicekit-power.h>
 #endif
 
 #include "gdm-languages.h"
@@ -53,7 +53,6 @@
 #include "gdm-session-option-widget.h"
 #include "gdm-timer.h"
 #include "gdm-profile.h"
-#include "gdm-common.h"
 
 #include "na-tray.h"
 
@@ -205,20 +204,20 @@ gdm_greeter_panel_move_resize_window (GdmGreeterPanel *panel,
 
         widget = GTK_WIDGET (panel);
 
-        g_assert (gtk_widget_get_realized (widget));
+        g_assert (GTK_WIDGET_REALIZED (widget));
 
         if (move && resize) {
-                gdk_window_move_resize (gtk_widget_get_window (widget),
+                gdk_window_move_resize (widget->window,
                                         panel->priv->geometry.x,
                                         panel->priv->geometry.y,
                                         panel->priv->geometry.width,
                                         panel->priv->geometry.height);
         } else if (move) {
-                gdk_window_move (gtk_widget_get_window (widget),
+                gdk_window_move (widget->window,
                                  panel->priv->geometry.x,
                                  panel->priv->geometry.y);
         } else if (resize) {
-                gdk_window_resize (gtk_widget_get_window (widget),
+                gdk_window_resize (widget->window,
                                    panel->priv->geometry.width,
                                    panel->priv->geometry.height);
         }
@@ -296,7 +295,7 @@ set_struts (GdmGreeterPanel *panel,
 
         gdk_error_trap_push ();
 
-        gdk_property_change (gtk_widget_get_window (GTK_WIDGET (panel)),
+        gdk_property_change (GTK_WIDGET (panel)->window,
                              gdk_atom_intern ("_NET_WM_STRUT_PARTIAL", FALSE),
                              gdk_atom_intern ("CARDINAL", FALSE),
                              32,
@@ -304,7 +303,7 @@ set_struts (GdmGreeterPanel *panel,
                              (guchar *) &data,
                              12);
 
-        gdk_property_change (gtk_widget_get_window (GTK_WIDGET (panel)),
+        gdk_property_change (GTK_WIDGET (panel)->window,
                              gdk_atom_intern ("_NET_WM_STRUT", FALSE),
                              gdk_atom_intern ("CARDINAL", FALSE),
                              32,
@@ -320,7 +319,7 @@ update_struts (GdmGreeterPanel *panel)
 {
         GdkRectangle geometry;
 
-        gdk_screen_get_monitor_geometry (gtk_window_get_screen (GTK_WINDOW (panel)),
+        gdk_screen_get_monitor_geometry (GTK_WINDOW (panel)->screen,
                                          panel->priv->monitor,
                                          &geometry);
 
@@ -338,12 +337,12 @@ update_geometry (GdmGreeterPanel *panel,
 {
         GdkRectangle geometry;
 
-        gdk_screen_get_monitor_geometry (gtk_window_get_screen (GTK_WINDOW (panel)),
+        gdk_screen_get_monitor_geometry (GTK_WINDOW (panel)->screen,
                                          panel->priv->monitor,
                                          &geometry);
 
         panel->priv->geometry.width = geometry.width;
-        panel->priv->geometry.height = requisition->height + 2 * gtk_container_get_border_width (GTK_CONTAINER (panel));
+        panel->priv->geometry.height = requisition->height + 2 * GTK_CONTAINER (panel)->border_width;
 
         panel->priv->geometry.x = geometry.x;
         panel->priv->geometry.y = geometry.y + geometry.height - panel->priv->geometry.height + (1.0 - panel->priv->progress) * panel->priv->geometry.height;
@@ -379,11 +378,11 @@ gdm_greeter_panel_real_size_request (GtkWidget      *widget,
         requisition->width  = panel->priv->geometry.width;
         requisition->height = panel->priv->geometry.height;
 
-        if (gtk_bin_get_child (bin) && gtk_widget_get_visible (gtk_bin_get_child (bin))) {
-                gtk_widget_size_request (gtk_bin_get_child (bin), requisition);
+        if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
+                gtk_widget_size_request (bin->child, requisition);
         }
 
-        if (! gtk_widget_get_realized (widget)) {
+        if (! GTK_WIDGET_REALIZED (widget)) {
                 return;
         }
 
@@ -552,13 +551,15 @@ can_suspend (void)
 {
         gboolean ret = FALSE;
 
-#ifdef HAVE_UPOWER
-        UpClient *up_client;
+#ifdef HAVE_DEVICEKIT_POWER
+        DkpClient *dkp_client;
 
-        /* use UPower to get data */
-        up_client = up_client_new ();
-	ret = up_client_get_can_suspend (up_client);
-        g_object_unref (up_client);
+        /* use DeviceKit-power to get data */
+        dkp_client = dkp_client_new ();
+        g_object_get (dkp_client,
+                      "can-suspend", &ret,
+                      NULL);
+        g_object_unref (dkp_client);
 #endif
 
         return ret;
@@ -567,20 +568,20 @@ can_suspend (void)
 static void
 do_system_suspend (void)
 {
-#ifdef HAVE_UPOWER
+#ifdef HAVE_DEVICEKIT_POWER
         gboolean ret;
-        UpClient *up_client;
+        DkpClient *dkp_client;
         GError *error = NULL;
 
-        /* use UPower to trigger suspend */
-        up_client = up_client_new ();
-        ret = up_client_suspend_sync (up_client, NULL, &error);
+        /* use DeviceKit-power to get data */
+        dkp_client = dkp_client_new ();
+        ret = dkp_client_suspend (dkp_client, &error);
         if (!ret) {
                 g_warning ("Couldn't suspend: %s", error->message);
                 g_error_free (error);
                 return;
         }
-        g_object_unref (up_client);
+        g_object_unref (dkp_client);
 #endif
 }
 
@@ -679,18 +680,17 @@ position_shutdown_menu (GtkMenu         *menu,
         GtkRequisition menu_requisition;
         GdkScreen *screen;
         int monitor;
-        GtkAllocation shutdown_button_allocation;
-        gtk_widget_get_allocation (panel->priv->shutdown_button, &shutdown_button_allocation);
+
         *push_in = TRUE;
 
         screen = gtk_widget_get_screen (GTK_WIDGET (panel));
-        monitor = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (GTK_WIDGET (panel)));
+        monitor = gdk_screen_get_monitor_at_window (screen, GTK_WIDGET (panel)->window);
         gtk_menu_set_monitor (menu, monitor);
 
         gtk_widget_translate_coordinates (GTK_WIDGET (panel->priv->shutdown_button),
                                           GTK_WIDGET (panel),
-                                          shutdown_button_allocation.x,
-                                          shutdown_button_allocation.y,
+                                          panel->priv->shutdown_button->allocation.x,
+                                          panel->priv->shutdown_button->allocation.y,
                                           x, y);
 
         gtk_window_get_position (GTK_WINDOW (panel), NULL, y);
@@ -728,7 +728,7 @@ setup_panel (GdmGreeterPanel *panel)
 
         gdm_profile_start (NULL);
 
-        gtk_widget_set_can_focus (GTK_WIDGET (panel), TRUE);
+        GTK_WIDGET_SET_FLAGS (GTK_WIDGET (panel), GTK_CAN_FOCUS);
 
         panel->priv->geometry.x      = -1;
         panel->priv->geometry.y      = -1;
@@ -793,14 +793,14 @@ setup_panel (GdmGreeterPanel *panel)
                 gtk_widget_show (panel->priv->hostname_label);
         }
 
-        if (!panel->priv->display_is_local || get_show_restart_buttons (panel)) {
+        if (panel->priv->display_is_local || get_show_restart_buttons (panel)) {
                 GtkWidget *menu_item;
                 GtkWidget *image;
 
                 panel->priv->shutdown_button = gtk_toggle_button_new ();
 
                 gtk_widget_set_tooltip_text (panel->priv->shutdown_button,
-                                             _("Shutdown Options…"));
+                                             _("Shutdown Options..."));
                 gtk_button_set_relief (GTK_BUTTON (panel->priv->shutdown_button),
                                        GTK_RELIEF_NONE);
 
@@ -820,7 +820,7 @@ setup_panel (GdmGreeterPanel *panel)
                         menu_item = gtk_menu_item_new_with_label ("Disconnect");
                         g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK (do_disconnect), NULL);
                         gtk_menu_shell_append (GTK_MENU_SHELL (panel->priv->shutdown_menu), menu_item);
-                } else if (get_show_restart_buttons (panel)) {
+                } else {
                         if (can_suspend ()) {
                                 menu_item = gtk_menu_item_new_with_label (_("Suspend"));
                                 g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK (do_system_suspend), NULL);
@@ -1103,16 +1103,8 @@ gdm_greeter_panel_set_default_session_name (GdmGreeterPanel *panel,
         if (session_name != NULL &&
             !gdm_option_widget_lookup_item (GDM_OPTION_WIDGET (panel->priv->session_option_widget),
                                             session_name, NULL, NULL, NULL)) {
-                if (strcmp (session_name, GDM_CUSTOM_SESSION) == 0) {
-                        gdm_option_widget_add_item (GDM_OPTION_WIDGET (panel->priv->session_option_widget),
-                                                    GDM_CUSTOM_SESSION,
-                                                    C_("customsession", "Custom"),
-                                                    _("Custom session"),
-                                                    GDM_OPTION_WIDGET_POSITION_TOP);
-                } else {
-                        g_warning ("Default session is not available");
-                        return;
-                }
+                g_warning ("Default session is not available");
+                return;
         }
 
         gdm_option_widget_set_default_item (GDM_OPTION_WIDGET (panel->priv->session_option_widget),
