@@ -26,9 +26,6 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include <dbus/dbus-glib.h>
-
-#include <glib.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
@@ -42,14 +39,6 @@
 #define GLOBAL_FACEDIR    DATADIR "/faces"
 #define MAX_FILE_SIZE     65536
 
-#define ACCOUNTS_NAME           "org.freedesktop.Accounts"
-#define ACCOUNTS_USER_INTERFACE "org.freedesktop.Accounts.User"
-
-enum {
-        PROP_0,
-        PROP_IS_LOADED
-};
-
 enum {
         CHANGED,
         SESSIONS_CHANGED,
@@ -59,29 +48,21 @@ enum {
 struct _GdmUser {
         GObject         parent;
 
-        DBusGConnection *connection;
-        DBusGProxy      *accounts_proxy;
-        DBusGProxy      *object_proxy;
-        DBusGProxyCall  *get_all_call;
-        char            *object_path;
-
         uid_t           uid;
         char           *user_name;
         char           *real_name;
-        char           *icon_file;
+        char           *home_dir;
+        char           *shell;
         GList          *sessions;
         gulong          login_frequency;
-
-        guint           is_loaded : 1;
 };
 
-struct _GdmUserClass
+typedef struct _GdmUserClass
 {
         GObjectClass parent_class;
-};
+} GdmUserClass;
 
 static void gdm_user_finalize     (GObject      *object);
-static gboolean check_user_file (const char *filename);
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
@@ -145,43 +126,6 @@ gdm_user_get_num_sessions (GdmUser    *user)
         return g_list_length (user->sessions);
 }
 
-static void
-gdm_user_set_property (GObject        *object,
-                       guint           prop_id,
-                       const GValue   *value,
-                       GParamSpec     *pspec)
-{
-        GdmUser *user;
-
-        user = GDM_USER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gdm_user_get_property (GObject        *object,
-                       guint           prop_id,
-                       GValue         *value,
-                       GParamSpec     *pspec)
-{
-        GdmUser *user;
-
-        user = GDM_USER (object);
-
-        switch (prop_id) {
-        case PROP_IS_LOADED:
-                g_value_set_boolean (value, user->is_loaded);
-                break;
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
 static void
 gdm_user_class_init (GdmUserClass *class)
 {
@@ -190,16 +134,6 @@ gdm_user_class_init (GdmUserClass *class)
         gobject_class = G_OBJECT_CLASS (class);
 
         gobject_class->finalize = gdm_user_finalize;
-        gobject_class->set_property = gdm_user_set_property;
-        gobject_class->get_property = gdm_user_get_property;
-
-        g_object_class_install_property (gobject_class,
-                                         PROP_IS_LOADED,
-                                         g_param_spec_boolean ("is-loaded",
-                                                               NULL,
-                                                               NULL,
-                                                               FALSE,
-                                                               G_PARAM_READABLE));
 
         signals [CHANGED] =
                 g_signal_new ("changed",
@@ -222,17 +156,9 @@ gdm_user_class_init (GdmUserClass *class)
 static void
 gdm_user_init (GdmUser *user)
 {
-        GError *error;
-
         user->user_name = NULL;
         user->real_name = NULL;
         user->sessions = NULL;
-
-        error = NULL;
-        user->connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
-        if (user->connection == NULL) {
-                g_warning ("Couldn't connect to system bus: %s", error->message);
-        }
 }
 
 static void
@@ -244,41 +170,19 @@ gdm_user_finalize (GObject *object)
 
         g_free (user->user_name);
         g_free (user->real_name);
-        g_free (user->icon_file);
-        g_free (user->object_path);
-
-        if (user->accounts_proxy != NULL) {
-                g_object_unref (user->accounts_proxy);
-        }
-
-        if (user->object_proxy != NULL) {
-                g_object_unref (user->object_proxy);
-        }
-
-        if (user->connection != NULL) {
-                dbus_g_connection_unref (user->connection);
-        }
 
         if (G_OBJECT_CLASS (gdm_user_parent_class)->finalize)
                 (*G_OBJECT_CLASS (gdm_user_parent_class)->finalize) (object);
 }
 
-static void
-set_is_loaded (GdmUser  *user,
-               gboolean  is_loaded)
-{
-        if (user->is_loaded != is_loaded) {
-                user->is_loaded = is_loaded;
-                g_object_notify (G_OBJECT (user), "is-loaded");
-        }
-}
-
 /**
  * _gdm_user_update_from_pwent:
  * @user: the user object to update.
  * @pwent: the user data to use.
  *
  * Updates the properties of @user using the data in @pwent.
+ *
+ * Since: 1.0
  **/
 void
 _gdm_user_update_from_pwent (GdmUser             *user,
@@ -289,7 +193,6 @@ _gdm_user_update_from_pwent (GdmUser             *user,
 
         g_return_if_fail (GDM_IS_USER (user));
         g_return_if_fail (pwent != NULL);
-        g_return_if_fail (user->object_path == NULL);
 
         changed = FALSE;
 
@@ -340,29 +243,11 @@ _gdm_user_update_from_pwent (GdmUser             *user,
 
         /* Username */
         if (g_strcmp0 (pwent->pw_name, user->user_name) != 0) {
-                g_free (user->icon_file);
-                user->icon_file = NULL;
-                if (pwent->pw_name != NULL) {
-                        gboolean      res;
-
-                        user->icon_file = g_build_filename (GDM_CACHE_DIR, pwent->pw_name, "face", NULL);
-
-                        res = check_user_file (user->icon_file);
-                        if (!res) {
-                                g_free (user->icon_file);
-                                user->icon_file = g_build_filename (GLOBAL_FACEDIR, pwent->pw_name, NULL);
-                        }
-                }
-
                 g_free (user->user_name);
                 user->user_name = g_strdup (pwent->pw_name);
                 changed = TRUE;
         }
 
-        if (!user->is_loaded) {
-                set_is_loaded (user, TRUE);
-        }
-
         if (changed) {
                 g_signal_emit (user, signals[CHANGED], 0);
         }
@@ -371,9 +256,10 @@ _gdm_user_update_from_pwent (GdmUser             *user,
 /**
  * _gdm_user_update_login_frequency:
  * @user: the user object to update
- * @login_frequency: the number of times the user has logged in
  *
  * Updates the login frequency of @user
+ *
+ * Since: 1.0
  **/
 void
 _gdm_user_update_login_frequency (GdmUser *user,
@@ -395,8 +281,10 @@ _gdm_user_update_login_frequency (GdmUser *user,
  *
  * Retrieves the ID of @user.
  *
- * Returns: (transfer none): a pointer to an array of characters which must not be modified or
+ * Returns: a pointer to an array of characters which must not be modified or
  *  freed, or %NULL.
+ *
+ * Since: 1.0
  **/
 
 gulong
@@ -413,8 +301,10 @@ gdm_user_get_uid (GdmUser *user)
  *
  * Retrieves the display name of @user.
  *
- * Returns: (transfer none): a pointer to an array of characters which must not be modified or
+ * Returns: a pointer to an array of characters which must not be modified or
  *  freed, or %NULL.
+ *
+ * Since: 1.0
  **/
 const char *
 gdm_user_get_real_name (GdmUser *user)
@@ -430,8 +320,10 @@ gdm_user_get_real_name (GdmUser *user)
  *
  * Retrieves the login name of @user.
  *
- * Returns: (transfer none): a pointer to an array of characters which must not be modified or
+ * Returns: a pointer to an array of characters which must not be modified or
  *  freed, or %NULL.
+ *
+ * Since: 1.0
  **/
 
 const char *
@@ -442,14 +334,6 @@ gdm_user_get_user_name (GdmUser *user)
         return user->user_name;
 }
 
-/**
- * gdm_user_get_login_frequency:
- * @user: a #GdmUser
- *
- * Returns the number of times @user has logged in.
- *
- * Returns: the login frequency
- */
 gulong
 gdm_user_get_login_frequency (GdmUser *user)
 {
@@ -547,6 +431,30 @@ check_user_file (const char *filename)
         return TRUE;
 }
 
+static GdkPixbuf *
+render_icon_from_cache (GdmUser *user,
+                        int      icon_size)
+{
+        GdkPixbuf  *retval;
+        char       *path;
+        gboolean    res;
+
+        path = g_build_filename (GDM_CACHE_DIR, user->user_name, "face", NULL);
+        res = check_user_file (path);
+        if (res) {
+                retval = gdk_pixbuf_new_from_file_at_size (path,
+                                                           icon_size,
+                                                           icon_size,
+                                                           NULL);
+        } else {
+                g_debug ("Could not access face icon %s", path);
+                retval = NULL;
+        }
+        g_free (path);
+
+        return retval;
+}
+
 static void
 rounded_rectangle (cairo_t *cr,
                    gdouble  aspect,
@@ -768,70 +676,65 @@ frame_pixbuf (GdkPixbuf *source)
         return dest;
 }
 
-/**
- * gdm_user_is_logged_in:
- * @user: a #GdmUser
- *
- * Returns whether or not #GdmUser is currently logged in.
- *
- * Returns: %TRUE or %FALSE
- */
 gboolean
 gdm_user_is_logged_in (GdmUser *user)
 {
         return user->sessions != NULL;
 }
 
-/**
- * gdm_user_render_icon:
- * @user: a #GdmUser
- * @icon_size: the size to render the icon at
- *
- * Returns a #GdkPixbuf of the account icon belonging to @user
- * at the pixel size specified by @icon_size.
- *
- * Returns: (transfer full): a #GdkPixbuf
- */
 GdkPixbuf *
 gdm_user_render_icon (GdmUser   *user,
                       gint       icon_size)
 {
         GdkPixbuf    *pixbuf;
         GdkPixbuf    *framed;
+        char         *path;
+        char         *tmp;
         gboolean      res;
-        GError       *error;
 
         g_return_val_if_fail (GDM_IS_USER (user), NULL);
         g_return_val_if_fail (icon_size > 12, NULL);
 
-        pixbuf = NULL;
-        if (user->icon_file) {
-                res = check_user_file (user->icon_file);
-                if (res) {
-                        pixbuf = gdk_pixbuf_new_from_file_at_size (user->icon_file,
-                                                                   icon_size,
-                                                                   icon_size,
-                                                                   NULL);
-                } else {
-                        pixbuf = NULL;
-                }
-        }
+        path = NULL;
 
+        pixbuf = render_icon_from_cache (user, icon_size);
         if (pixbuf != NULL) {
                 goto out;
         }
 
-        error = NULL;
-        pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-
-                                           "avatar-default",
-                                           icon_size,
-                                           GTK_ICON_LOOKUP_FORCE_SIZE,
-                                           &error);
-        if (error) {
-                g_warning ("%s", error->message);
-                g_error_free (error);
+        /* Try ${GlobalFaceDir}/${username} */
+        path = g_build_filename (GLOBAL_FACEDIR, user->user_name, NULL);
+        res = check_user_file (path);
+        if (res) {
+                pixbuf = gdk_pixbuf_new_from_file_at_size (path,
+                                                           icon_size,
+                                                           icon_size,
+                                                           NULL);
+        } else {
+                g_debug ("Could not access global face icon %s", path);
+                pixbuf = NULL;
         }
+
+        g_free (path);
+        if (pixbuf != NULL) {
+                goto out;
+        }
+
+        /* Finally, ${GlobalFaceDir}/${username}.png */
+        tmp = g_strconcat (user->user_name, ".png", NULL);
+        path = g_build_filename (GLOBAL_FACEDIR, tmp, NULL);
+        g_free (tmp);
+        res = check_user_file (path);
+        if (res) {
+                pixbuf = gdk_pixbuf_new_from_file_at_size (path,
+                                                           icon_size,
+                                                           icon_size,
+                                                           NULL);
+        } else {
+                g_debug ("Could not access global face icon %s", path);
+                pixbuf = NULL;
+        }
+        g_free (path);
  out:
 
         if (pixbuf != NULL) {
@@ -845,49 +748,6 @@ gdm_user_render_icon (GdmUser   *user,
         return pixbuf;
 }
 
-/**
- * gdm_user_get_icon_file:
- * @user: a #GdmUser
- *
- * Returns the path to the account icon belonging to @user.
- *
- * Returns: (transfer none): a path to an icon
- */
-const char *
-gdm_user_get_icon_file (GdmUser *user)
-{
-        g_return_val_if_fail (GDM_IS_USER (user), NULL);
-
-        return user->icon_file;
-}
-
-/**
- * gdm_user_get_object_path:
- * @user: a #GdmUser
- *
- * Returns the user accounts service object path of @user,
- * or %NULL if @user doesn't have an object path associated
- * with it.
- *
- * Returns: (transfer none): the primary ConsoleKit session id of the user
- */
-const char *
-gdm_user_get_object_path (GdmUser *user)
-{
-        g_return_val_if_fail (GDM_IS_USER (user), NULL);
-
-        return user->object_path;
-}
-
-/**
- * gdm_user_get_primary_session_id:
- * @user: a #GdmUser
- *
- * Returns the primary ConsoleKit session id of @user, or %NULL if @user isn't
- * logged in.
- *
- * Returns: (transfer none): the primary ConsoleKit session id of the user
- */
 const char *
 gdm_user_get_primary_session_id (GdmUser *user)
 {
@@ -901,196 +761,3 @@ gdm_user_get_primary_session_id (GdmUser *user)
         return user->sessions->data;
 }
 
-static void
-collect_props (const gchar    *key,
-               const GValue   *value,
-               GdmUser        *user)
-{
-        gboolean handled = TRUE;
-
-        if (strcmp (key, "Uid") == 0) {
-                user->uid = g_value_get_uint64 (value);
-        } else if (strcmp (key, "UserName") == 0) {
-                g_free (user->user_name);
-                user->user_name = g_value_dup_string (value);
-        } else if (strcmp (key, "RealName") == 0) {
-                g_free (user->real_name);
-                user->real_name = g_value_dup_string (value);
-        } else if (strcmp (key, "AccountType") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "Email") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "Language") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "Location") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "LoginFrequency") == 0) {
-                user->login_frequency = g_value_get_uint64 (value);
-        } else if (strcmp (key, "IconFile") == 0) {
-                gboolean res;
-
-                g_free (user->icon_file);
-                user->icon_file = g_value_dup_string (value);
-
-                res = check_user_file (user->icon_file);
-                if (!res) {
-                        g_free (user->icon_file);
-                        user->icon_file = g_build_filename (GLOBAL_FACEDIR, user->user_name, NULL);
-                }
-        } else if (strcmp (key, "Locked") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "AutomaticLogin") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "PasswordMode") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "PasswordHint") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "HomeDirectory") == 0) {
-                /* ignore */
-        } else if (strcmp (key, "Shell") == 0) {
-                /* ignore */
-        } else {
-                handled = FALSE;
-        }
-
-        if (!handled) {
-                g_debug ("unhandled property %s", key);
-        }
-}
-
-static void
-on_get_all_finished (DBusGProxy     *proxy,
-                     DBusGProxyCall *call,
-                     GdmUser        *user)
-{
-        GError      *error;
-        GHashTable  *hash_table;
-        gboolean     res;
-
-        g_assert (user->get_all_call == call);
-        g_assert (user->object_proxy == proxy);
-
-        error = NULL;
-        res = dbus_g_proxy_end_call (proxy,
-                                     call,
-                                     &error,
-                                     dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE),
-                                     &hash_table,
-                                     G_TYPE_INVALID);
-        user->get_all_call = NULL;
-        user->object_proxy = NULL;
-
-        if (! res) {
-                g_debug ("Error calling GetAll() when retrieving properties for %s: %s",
-                         user->object_path, error->message);
-                g_error_free (error);
-                goto out;
-        }
-        g_hash_table_foreach (hash_table, (GHFunc) collect_props, user);
-        g_hash_table_unref (hash_table);
-
-        if (!user->is_loaded) {
-                set_is_loaded (user, TRUE);
-        }
-
-        g_signal_emit (user, signals[CHANGED], 0);
-
-out:
-        g_object_unref (proxy);
-}
-
-static gboolean
-update_info (GdmUser *user)
-{
-        DBusGProxy     *proxy;
-        DBusGProxyCall *call;
-
-        proxy = dbus_g_proxy_new_for_name (user->connection,
-                                           ACCOUNTS_NAME,
-                                           user->object_path,
-                                           DBUS_INTERFACE_PROPERTIES);
-
-        call = dbus_g_proxy_begin_call (proxy,
-                                        "GetAll",
-                                        (DBusGProxyCallNotify)
-                                        on_get_all_finished,
-                                        user,
-                                        NULL,
-                                        G_TYPE_STRING,
-                                        ACCOUNTS_USER_INTERFACE,
-                                        G_TYPE_INVALID);
-
-        if (call == NULL) {
-                g_warning ("GdmUser: failed to make GetAll call");
-                goto failed;
-        }
-
-        user->get_all_call = call;
-        user->object_proxy = proxy;
-        return TRUE;
-
-failed:
-        if (proxy != NULL) {
-                g_object_unref (proxy);
-        }
-
-        return FALSE;
-}
-
-static void
-changed_handler (DBusGProxy *proxy,
-                 gpointer   *data)
-{
-        GdmUser *user = GDM_USER (data);
-
-        update_info (user);
-}
-
-/**
- * _gdm_user_update_from_object_path:
- * @user: the user object to update.
- * @object_path: the object path of the user to use.
- *
- * Updates the properties of @user from the accounts service via
- * the object path in @object_path.
- **/
-void
-_gdm_user_update_from_object_path (GdmUser    *user,
-                                   const char *object_path)
-{
-        g_return_if_fail (GDM_IS_USER (user));
-        g_return_if_fail (object_path != NULL);
-        g_return_if_fail (user->object_path == NULL);
-
-        user->object_path = g_strdup (object_path);
-
-        user->accounts_proxy = dbus_g_proxy_new_for_name (user->connection,
-                                                          ACCOUNTS_NAME,
-                                                          user->object_path,
-                                                          ACCOUNTS_USER_INTERFACE);
-        dbus_g_proxy_set_default_timeout (user->accounts_proxy, INT_MAX);
-        dbus_g_proxy_add_signal (user->accounts_proxy, "Changed", G_TYPE_INVALID);
-
-        dbus_g_proxy_connect_signal (user->accounts_proxy, "Changed",
-                                     G_CALLBACK (changed_handler), user, NULL);
-
-        if (!update_info (user)) {
-                g_warning ("Couldn't update info for user with object path %s", object_path);
-        }
-}
-
-/**
- * gdm_user_is_loaded:
- * @user: a #GdmUser
- *
- * Determines whether or not the user object is loaded and ready to read from.
- * #GdmUserManager:is-loaded property must be %TRUE before calling
- * gdm_user_manager_list_users()
- *
- * Returns: %TRUE or %FALSE
- */
-gboolean
-gdm_user_is_loaded (GdmUser *user)
-{
-        return user->is_loaded;
-}
