@@ -20,9 +20,9 @@
 
 #include "config.h"
 
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <stdlib.h>
 #include <sys/types.h>
 
 #include <glib/gi18n.h>
@@ -79,8 +79,7 @@ typedef struct _GdmAppletData
         guint           client_notify_lockdown_id;
 
         guint           current_status;
-        guint           user_loaded_notify_id;
-        guint           user_changed_notify_id;
+        guint           user_notify_id;
         gint8           pixel_size;
         gint            panel_size;
         GtkIconSize     icon_size;
@@ -328,7 +327,7 @@ applet_change_background_cb (PanelApplet               *applet,
                 gtk_widget_modify_bg (adata->menubar, GTK_STATE_NORMAL, color);
                 break;
         case PANEL_PIXMAP_BACKGROUND:
-                style = gtk_style_copy (gtk_widget_get_style (adata->menubar));
+                style = gtk_style_copy (adata->menubar->style);
                 if (style->bg_pixmap[GTK_STATE_NORMAL]) {
                         g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
                 }
@@ -392,7 +391,7 @@ set_item_text_angle_and_alignment (GtkWidget *item,
 {
         GtkWidget *label;
 
-        label = gtk_bin_get_child (GTK_BIN (item));
+        label = GTK_BIN (item)->child;
 
         gtk_label_set_angle (GTK_LABEL (label), text_angle);
 
@@ -435,11 +434,11 @@ applet_size_allocate_cb (GtkWidget     *widget,
         case PANEL_APPLET_ORIENT_UP:
         case PANEL_APPLET_ORIENT_DOWN:
                 gtk_widget_set_size_request (top_item, -1, allocation->height);
-                pixel_size = allocation->height - gtk_widget_get_style (top_item)->ythickness * 2;
+                pixel_size = allocation->height - top_item->style->ythickness * 2;
                 break;
         case PANEL_APPLET_ORIENT_LEFT:
                 gtk_widget_set_size_request (top_item, allocation->width, -1);
-                pixel_size = allocation->width - gtk_widget_get_style (top_item)->xthickness * 2;
+                pixel_size = allocation->width - top_item->style->xthickness * 2;
                 pack_direction = GTK_PACK_DIRECTION_TTB;
                 text_angle = 270.0;
                 text_xalign = 0.5;
@@ -447,7 +446,7 @@ applet_size_allocate_cb (GtkWidget     *widget,
                 break;
         case PANEL_APPLET_ORIENT_RIGHT:
                 gtk_widget_set_size_request (top_item, allocation->width, -1);
-                pixel_size = allocation->width - gtk_widget_get_style (top_item)->xthickness * 2;
+                pixel_size = allocation->width - top_item->style->xthickness * 2;
                 pack_direction = GTK_PACK_DIRECTION_BTT;
                 text_angle = 90.0;
                 text_xalign = 0.5;
@@ -480,13 +479,7 @@ gdm_applet_data_free (GdmAppletData *adata)
 {
         gconf_client_notify_remove (adata->client, adata->client_notify_lockdown_id);
 
-        if (adata->user_loaded_notify_id != 0) {
-                g_signal_handler_disconnect (adata->user, adata->user_loaded_notify_id);
-        }
-
-        if (adata->user_changed_notify_id != 0) {
-                g_signal_handler_disconnect (adata->user, adata->user_changed_notify_id);
-        }
+        g_signal_handler_disconnect (adata->user, adata->user_notify_id);
 
 #ifdef BUILD_PRESENSE_STUFF
         if (adata->presence_proxy != NULL) {
@@ -516,10 +509,8 @@ menubar_expose_event_cb (GtkWidget      *widget,
                          GdkEventExpose *event,
                          GdmAppletData  *adata)
 {
-        if (gtk_widget_has_focus (GTK_WIDGET (adata->applet)))
-                gtk_paint_focus (gtk_widget_get_style (widget),
-                                 gtk_widget_get_window (widget),
-                                 gtk_widget_get_state (widget),
+        if (GTK_WIDGET_HAS_FOCUS (adata->applet))
+                gtk_paint_focus (widget->style, widget->window, GTK_WIDGET_STATE (widget),
                                  NULL, widget, "menu-applet", 0, 0, -1, -1);
 
         return FALSE;
@@ -604,16 +595,7 @@ static gboolean
 menu_expose_cb (GtkWidget *menu,
                 gpointer   data)
 {
-        char *program;
-        GdmAppletData *adata = data;
 
-        program = g_find_program_in_path ("gnome-control-center");
-        if (program != NULL) {
-                gtk_widget_show (adata->control_panel_item);
-        } else {
-                gtk_widget_hide (adata->control_panel_item);
-        }
-        g_free (program);
         return FALSE;
 }
 
@@ -807,12 +789,9 @@ on_account_activate (GtkMenuItem   *item,
         GdkScreen *screen;
         gboolean   res;
 
-        args[0] = g_find_program_in_path ("accounts-dialog");
+        args[0] = g_find_program_in_path ("gnome-about-me");
         if (args[0] == NULL) {
-                args[0] = g_find_program_in_path ("gnome-about-me");
-                if (args[0] == NULL) {
-                        return;
-                }
+                return;
         }
         args[1] = NULL;
 
@@ -892,7 +871,7 @@ on_quit_session_activate (GtkMenuItem   *item,
                                    NULL,
                                    &error);
         if (! res) {
-                g_warning (_("Can't log out: %s"), error->message);
+                g_warning (_("Can't logout: %s"), error->message);
                 g_error_free (error);
         }
 
@@ -1069,6 +1048,7 @@ create_sub_menu (GdmAppletData *adata)
                           G_CALLBACK (menu_style_set_cb), adata);
         g_signal_connect (adata->menu, "show",
                           G_CALLBACK (menu_expose_cb), adata);
+        gtk_widget_show (adata->menu);
 
 #ifdef BUILD_PRESENSE_STUFF
         adata->user_item = gdm_entry_menu_item_new ();
@@ -1146,6 +1126,8 @@ create_sub_menu (GdmAppletData *adata)
                           G_CALLBACK (menuitem_style_set_cb), adata);
         g_signal_connect (adata->control_panel_item, "activate",
                           G_CALLBACK (on_control_panel_activate), adata);
+        gtk_widget_show (adata->control_panel_item);
+
 
         item = gtk_separator_menu_item_new ();
         gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), item);
@@ -1173,7 +1155,7 @@ create_sub_menu (GdmAppletData *adata)
                           G_CALLBACK (on_login_screen_activate), adata);
         /* Only show switch user if there are other users */
 
-        adata->quit_session_item = gtk_image_menu_item_new_with_label (_("Quit…"));
+        adata->quit_session_item = gtk_image_menu_item_new_with_label (_("Quit..."));
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->quit_session_item),
                                        gtk_image_new ());
         gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu),
@@ -1183,7 +1165,6 @@ create_sub_menu (GdmAppletData *adata)
         g_signal_connect (adata->quit_session_item, "activate",
                           G_CALLBACK (on_quit_session_activate), adata);
         gtk_widget_show (adata->quit_session_item);
-        gtk_widget_show (adata->menu);
 }
 
 static void
@@ -1269,66 +1250,40 @@ reset_icon (GdmAppletData *adata)
 #endif
 }
 
-static void
-setup_current_user_now (GdmAppletData *adata)
-{
-        g_assert (adata->user != NULL);
-
-        if (adata->user_loaded_notify_id != 0) {
-                g_signal_handler_disconnect (adata->user, adata->user_loaded_notify_id);
-        }
-        adata->user_loaded_notify_id = 0;
-
-        update_label (adata);
-        reset_icon (adata);
-        adata->user_changed_notify_id =
-            g_signal_connect (adata->user,
-                              "changed",
-                              G_CALLBACK (on_user_changed),
-                              adata);
-}
-
-static void
-on_current_user_loaded (GdmUser       *user,
-                        GParamSpec    *pspec,
-                        GdmAppletData *adata)
-{
-        if (!gdm_user_is_loaded (user)) {
-                return;
-        }
-
-        setup_current_user_now (adata);
-}
-
 static void
 setup_current_user (GdmAppletData *adata)
 {
-        adata->user = gdm_user_manager_get_user_by_uid (adata->manager, getuid ());
+        const char *name;
+        GtkWidget  *label;
 
-        if (adata->user == NULL) {
-                g_warning ("Could not setup current user");
-                return;
+        adata->user = gdm_user_manager_get_user_by_uid (adata->manager, getuid ());
+        if (adata->user != NULL) {
+                g_object_ref (adata->user);
+                name = gdm_user_get_real_name (adata->user);
+        } else {
+                name = _("Unknown");
         }
 
-        g_object_ref (adata->user);
-
-        adata->menuitem = gtk_image_menu_item_new_with_label ("");
+        adata->menuitem = gtk_image_menu_item_new_with_label (name);
 #ifndef BUILD_PRESENSE_STUFF
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->menuitem),
                                        gtk_image_new ());
 #endif
+        label = GTK_BIN (adata->menuitem)->child;
         gtk_menu_shell_append (GTK_MENU_SHELL (adata->menubar), adata->menuitem);
         gtk_widget_show (adata->menuitem);
 
-        if (gdm_user_is_loaded (adata->user)) {
-                setup_current_user_now (adata);
-                return;
-        }
+        update_label (adata);
 
-        adata->user_loaded_notify_id = g_signal_connect (adata->user,
-                                                         "notify::is-loaded",
-                                                         G_CALLBACK (on_current_user_loaded),
-                                                         adata);
+        if (adata->user != NULL) {
+                reset_icon (adata);
+
+                adata->user_notify_id =
+                        g_signal_connect (adata->user,
+                                          "changed",
+                                          G_CALLBACK (on_user_changed),
+                                          adata);
+        }
 }
 
 #ifdef BUILD_PRESENSE_STUFF
@@ -1421,7 +1376,7 @@ fill_applet (PanelApplet *applet)
                 gtk_window_set_default_icon_name ("stock_people");
                 g_set_application_name (_("User Switch Applet"));
 
-                if (! gdm_settings_client_init (DATADIR "/gdm/gdm.schemas", "/")) {
+                if (! gdm_settings_client_init (GDMCONFDIR "/gdm.schemas", "/")) {
                         g_critical ("Unable to initialize settings client");
                         exit (1);
                 }
@@ -1506,7 +1461,8 @@ fill_applet (PanelApplet *applet)
 
         adata->menubar = gtk_menu_bar_new ();
         gtk_widget_set_name (adata->menubar, "gdm-user-switch-menubar");
-        gtk_widget_set_can_focus (adata->menubar, TRUE);
+        GTK_WIDGET_SET_FLAGS (adata->menubar,
+                              GTK_WIDGET_FLAGS (adata->menubar) | GTK_CAN_FOCUS);
         g_signal_connect (adata->menubar, "button-press-event",
                           G_CALLBACK (menubar_button_press_event_cb), adata);
         g_signal_connect_after (adata->menubar, "expose-event",
